@@ -1,4 +1,4 @@
-# $Id: Document.pm 42299 2014-09-26 14:30:54Z wsl $
+# $Id: Document.pm 37565 2012-08-15 19:01:35Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Attributes/Document.pm $
 
 use strict;
@@ -7,15 +7,16 @@ use utf8;
 
 package Aselect::UI::Attributes::Document;
 
-use Aselect::UI::Document -self;
+use Xyzzy::Util qw(iso8601);
 
-use constant rootname => 'attributes';
+use Aselect::UI::Document -self;
 
 sub build {
 	my $req = $self->req;
 	my $cfg = $self->cfg;
 
-	my $root = $self->documentElement;
+	my $root = $self->construct('attributes');
+	$self->setDocumentElement($root);
 
 	if(my $uid = $req->new_session->uid) {
 		my $requestors = $cfg->requestors;
