@@ -1,4 +1,4 @@
-# $Id: Document.pm 45950 2016-12-06 16:00:03Z wsl $
+# $Id: Document.pm 35814 2011-10-20 12:09:53Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Giveup/Document.pm $
 
 use strict;
@@ -9,7 +9,9 @@ package Aselect::UI::Giveup::Document;
 
 use Aselect::UI::Login::Document -self;
 
-use constant rootname => 'giveup';
+sub build {
+	$self->setDocumentElement($self->construct('giveup'));
+}
 
 sub response {
 	my $res = super;
@@ -17,7 +19,7 @@ sub response {
 	my $req = $self->req;
 
 	if($req->effective_warn eq 'false') {
-		$res->status(303);
+		$res->status(302);
 		$res->setheader(Location => $req->bare_url);
 	}
 
