@@ -1,4 +1,4 @@
-# $Id: Request.pm 42299 2014-09-26 14:30:54Z wsl $
+# $Id: Request.pm 36180 2011-12-08 13:57:04Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Giveup/Request.pm $
 
 use strict;
@@ -9,5 +9,4 @@ package Aselect::UI::Giveup::Request;
 
 use Aselect::Request -self;
 
-use constant credentials => 'failed';
-use constant uid => undef;
+const credentials => 'failed';
