@@ -1,4 +1,4 @@
-# $Id: Request.pm 46395 2017-03-15 15:42:50Z wsl $
+# $Id: Request.pm 39230 2013-04-16 10:20:15Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/SPNEGO/Request.pm $
 
 use strict;
@@ -34,9 +34,6 @@ const decoded => sub {
 	eval {
 		my $binary = decode_base64($negotiate);
 
-		die "ignoring NTLM attempt (insecure, deprecated)\n"
-			if substr($binary, 0, 8) eq "NTLMSSP\0";
-
 		my $asn1 = $self->cfg->asn1;
 		$decoded = $asn1->decode($binary)
 			or die $asn1->error;
@@ -75,8 +72,8 @@ const feasible => sub {
 	return 1 if $setting eq 'true';
 
 	if(my $re = $cfg->spnego_useragent) {
-		my $ua = $self->user_agent // '';
-		return 1 if $ua =~ $re;
+		my $ua = $self->user_agent;
+		return 1 if defined $ua && $ua =~ $re;
 	}
 
 	return undef;
