@@ -1,4 +1,4 @@
-# $Id: Document.pm 42299 2014-09-26 14:30:54Z wsl $
+# $Id: Document.pm 35761 2011-10-12 18:45:02Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Status/Document.pm $
 
 use strict;
@@ -9,4 +9,6 @@ package Aselect::UI::Status::Document;
 
 use Aselect::UI::Document -self;
 
-use constant rootname => 'status';
+sub build {
+	$self->setDocumentElement($self->construct('status'));
+}
